# hdob - The Hex, Decimal, Octal, Binary converter

![](https://raw.githubusercontent.com/housechou/hdob/master/images/screenshot.png)

## System Requirement
Python3

## Install
```bash
python3 -m pip install --user hdob
```

## Run
```bash
hdob
```
